==> pystacks-0.1.tar.gz: pystacks-0.1/pystacks/criteria.py <==
__author__ = 'victor'
import theano.tensor as T

def mean_squared_loss(a, y):
    """
    Returns the means squared loss computed as

    .. math::
        J = \sum_t^T \sum_k (a^{(t)}-y^{(t)})_k^2

    :param a: predictions
    :param y: a one hot encoding of the target labels
    :return: mean squared loss
    """
    return 0.5 * T.mean(T.sum((a-y)**2, axis=1), axis=0)

def cross_entropy_loss(a, y):
    """
    Compute the cross entropy loss over a softmax

    .. math::
        J = \frac{1}{T} \sum_t^T \sum_k - (y * \log a)_k

    :param a: predictions
    :param y: a one hot encoding of the target labels
    :return: cross entropy loss
    """
    return - T.mean(T.sum(y * T.log(a), axis=1), axis=0)

def max_margin_loss(a_true, a_false, margin=1):
    """
    Computes the max margin loss

    .. math::
        J = \frac{1}{T} \sum_t^T (\sum_k max(0, 1 - a_{true}^{(t)} - a_{false}^{(t)}))_k

    :param a_true: scores for the correct example
    :param a_false: scores for the corresponding corrupted example
    :param margin: margin to use
    :return: max margin loss
    """
    margins = margin - a_true + a_false
    return T.sum(T.maximum(0, margins))

def negative_sampling_loss(a_true, a_false_list):
    """
    Computes the negative sampling loss

    .. math::
        J = - \log a_{true} - \sum_c^C \log (1 - a_{false, c})

    :param a_true: probabilities for the true examples
    :param a_false_list: list of probabilities for the corresponding false examples
    :return: negative sampling loss
    """
    return -T.log(a_true) - T.sum([T.log(1-a_false) for a_false in a_false_list], axis=0)

==> pystacks-0.2.tar.gz: pystacks-0.2/pystacks/criteria.py <==
__author__ = 'victor'
import theano.tensor as T

def mean_squared_loss(a, y):
    r""" Returns the means squared loss computed as

    .. math::
        J = \sum_t^T \sum_k (a^{(t)}-y^{(t)})_k^2

    :param a: predictions
    :param y: a one hot encoding of the target labels
    :return: mean squared loss
    """
    return 0.5 * T.mean(T.sum((a-y)**2, axis=1), axis=0)

def cross_entropy_loss(a, y):
    r""" Compute the cross entropy loss over a softmax

    .. math::
        J = \frac{1}{T} \sum_t^T \sum_k - (y * \log a)_k

    :param a: predictions
    :param y: a one hot encoding of the target labels
    :return: cross entropy loss
    """
    return - T.mean(T.sum(y * T.log(a), axis=1), axis=0)

def max_margin_loss(a_true, a_false, margin=1):
    r""" Computes the max margin loss

    .. math::
        J = \frac{1}{T} \sum_t^T (\sum_k max(0, 1 - a_{true}^{(t)} - a_{false}^{(t)}))_k

    :param a_true: scores for the correct example
    :param a_false: scores for the corresponding corrupted example
    :param margin: margin to use
    :return: max margin loss
    """
    margins = margin - a_true + a_false
    return T.sum(T.maximum(0, margins))

def negative_sampling_loss(a_true, a_false_list):
    r""" Computes the negative sampling loss

    .. math::
        J = - \log a_{true} - \sum_c^C \log (1 - a_{false, c})

    :param a_true: probabilities for the true examples
    :param a_false_list: list of probabilities for the corresponding false examples
    :return: negative sampling loss
    """
    return -T.log(a_true) - T.sum([T.log(1-a_false) for a_false in a_false_list], axis=0)
